/**
 * Pulls nodes toward a specified `(x, y)` target point.
 */
function attract(target) {

  var nodes = void 0,
      targets = void 0,
      strength = 0.1;

  function force(alpha) {
    var node = void 0,
        target = void 0;
    for (var i = 0; i < nodes.length; i++) {
      node = nodes[i];
      target = targets[i];
      node.vx += (target[0] - node.x) * strength * alpha;
      node.vy += (target[1] - node.y) * strength * alpha;
    }
  }

  function initialize() {
    if (!nodes) return;

    // populate local `targets` using `target` accessor
    targets = new Array(nodes.length);
    for (var i = 0; i < nodes.length; i++) {
      targets[i] = target(nodes[i], i, nodes);
    }
  }

  force.initialize = function (_) {
    nodes = _;
    initialize();
  };

  force.strength = function (_) {
    return _ == null ? strength : (strength = +_, force);
  };

  force.target = function (_) {
    // keep existing value if passed invalid value
    if (_ == null) return _ = target;

    // coerce `target` accessor into a function
    target = typeof _ === 'function' ? _ : function () {
      return _;
    };

    // reinitialize
    initialize();

    // allow chaining
    return force;
  };

  if (!target) force.target([0, 0]);
  return force;
}

export { attract as forceAttract };
//# sourceMappingURL=d3-force-attract.mjs.map
